@@ -14,9 +14,7 @@ def _default_json_default(obj):
     Coerce everything to strings.
     All objects representing time get output as ISO8601.
     """
-    if isinstance(obj, datetime.datetime) or \
-       isinstance(obj,datetime.date) or      \
-       isinstance(obj,datetime.time):
+    if isinstance(obj, (datetime.datetime, datetime.date, datetime.time)):
         return obj.isoformat()
     else:
         return str(obj)
@@ -116,7 +114,7 @@ class LogstashFormatter(logging.Formatter):
         True
         """
         return dict(defaults.get('@fields', {}).items() + fields.items())
-    
+
 
 class LogstashFormatterV1(LogstashFormatter):
     """
@@ -142,7 +140,7 @@ class LogstashFormatterV1(LogstashFormatter):
         if 'exc_text' in fields and not fields['exc_text']:
             fields.pop('exc_text')
 
-	now = datetime.datetime.utcnow()
+        now = datetime.datetime.utcnow()
         base_log = {'@timestamp': now.strftime("%Y-%m-%dT%H:%M:%S") + ".%03d" % (now.microsecond / 1000) + "Z",
                     '@version': 1,
                     'source_host': self.source_host}
